summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoTemplateChooseDia.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficeui/KoTemplateChooseDia.h')
-rw-r--r--lib/kofficeui/KoTemplateChooseDia.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/kofficeui/KoTemplateChooseDia.h b/lib/kofficeui/KoTemplateChooseDia.h
index 5bedde84..d39bc7ee 100644
--- a/lib/kofficeui/KoTemplateChooseDia.h
+++ b/lib/kofficeui/KoTemplateChooseDia.h
@@ -49,7 +49,7 @@ class KoTCDIconCanvas : public KIconCanvas
: KIconCanvas( parent, name ) {}
bool isCurrentValid() { return currentItem(); }
- TQIconViewItem * load(KoTemplateGroup *group, const TQString& name, KInstance* instance);
+ TQIconViewItem * load(KoTemplateGroup *group, const TQString& name, TDEInstance* instance);
protected:
virtual void keyPressEvent( TQKeyEvent *e ) {
@@ -118,7 +118,7 @@ class KoTCDRecentFilesIconView : public KFileIconView {
TQLabel* toolTip;
};
-class KInstance;
+class TDEInstance;
class KoTemplateChooseDiaPrivate;
/**
@@ -159,7 +159,7 @@ public:
* This is the static method you'll normally use to show the
* dialog.
*
* @param instance the KInstance of your app
* The native mimetype is retrieved from the (desktop file of) that instance.
* @param file this is the filename which is returned to your app
* More precisely, it's a url (to give to KURL) if ReturnType is File
@@ -171,14 +171,14 @@ public:
* @param parent pointer to parent widget
* @return The return type (see above)
*/
- static ReturnType choose(KInstance* instance, TQString &file,
+ static ReturnType choose(TDEInstance* instance, TQString &file,
const DialogType &dialogType,
const TQCString& templateType,
TQWidget* parent);
private:
/// Ditto, with extraNativeMimeTypes added
- static ReturnType choose(KInstance* instance, TQString &file,
+ static ReturnType choose(TDEInstance* instance, TQString &file,
const TQCString &format,
const TQString &nativeName,
const TQStringList& extraNativeMimeTypes,
@@ -215,7 +215,7 @@ private:
*
* @param parent parent the parent of the dialog
* @param name the TQt internal name
* @param instance the KInstance of your app
* @param format is the mimetype of the app (e.g. application/x-kspread)
* @param nativeName is the name of your app (e.g KSpread)
* @param dialogType the type of the dialog
@@ -224,7 +224,7 @@ private:
*
* @return The return type (see above)
*/
- KoTemplateChooseDia(TQWidget *parent, const char *name, KInstance* instance,
+ KoTemplateChooseDia(TQWidget *parent, const char *name, TDEInstance* instance,
const TQCString &format,
const TQString &nativeName,
const TQStringList &extraNativeMimeTypes,
@@ -159,7 +159,7 @@ public:
* dialog.
*
- * @param instance the KInstance of your app
+ * @param instance the TDEInstance of your app
* The native mimetype is retrieved from the (desktop file of) that instance.
* @param file this is the filename which is returned to your app
@@ -215,7 +215,7 @@ private:
* @param parent parent the parent of the dialog
* @param name the TQt internal name
- * @param instance the KInstance of your app
+ * @param instance the TDEInstance of your app
* @param format is the mimetype of the app (e.g. application/x-kspread)
* @param nativeName is the name of your app (e.g KSpread)